
********************************************
*
*Instructions
*
********************************************

*This is the datafile that contains all variables to replicate the results reported as part of the Danish study 
*both in the maintext and the Online Appendix.
*Note, the dataset is under embargo nd only the variables used in this paper are provided.
*First, line 14 till 131 will coded the variables used in this study
*Second, next all coded to reproduce the findings are provided

********************************************
*
*Create dependent variable used in the study
*
********************************************

********************************************
*Change between vote choice in 2007 and vote intention at time of the survey
********************************************
*Vote in 2007 elections
ta v2010_stemte_fv07
*Vote intention at time of the survey in 2010
ta v2010_partivalg
*create switch variable
ge skift1 = v2010_stemte_fv07- v2010_partivalg
*0 is stable, all other numbers indicate a change. Recode so that change == 1 
recode skift1 (-32/-1=1)
recode skift1 (1/32=1)

*************************************************************
*Change between vote intention in 2010 and self-reported vote in 2011 election
*************************************************************
*Vote intention at time of the survey in 2010
ta v2010_partivalg
*Vote in 2011 election
ta v2011_stemte_fv011
*create switch variable
ge skift2= v2010_partivalg-v2011_stemte_fv011
*0 is stable, all other numbers indicate a change. Recode so that change == 1 
recode skift2 (-32/-1=1)
recode skift2 (1/32=1)

*************************************************************
*Change between self-reported vote in 2011 election and vote intention at time of the survey in 2011
*************************************************************
*Vote in 2011 election
ta v2011_stemte_fv011
*Vote intention at time of the survey in 2010
ta v2011_partivalg
*create switch variable
ge skift3= v2011_stemte_fv011-v2011_partivalg
*0 is stable, all other numbers indicate a change. Recode so that change == 1 
recode skift3 (-32/-1=1)
recode skift3 (1/32=1)

*************************************************************
*Create change variable used in the survey
*************************************************************
ge lability = skift1 +skift2 +skift3
label variable lability "Dependent variable: Vote switching"

********************************************
*
*Personality variables
*
********************************************

*The items are not included here because the personality inventory is under copy-right protection
su v2010_open v2010_con v2010_ext v2010_agre v2010_neu

********************************************
*
*Covariates
*
********************************************

********************************************
*Education (2010)
********************************************
gen v2010_education = v2010_sidstuddands
*recode education
recode v2010_education (1=1) (4 5 =2) (2 3 =3) (6=4) (7 8 9 = 5)

********************************************
*Age (2010)
********************************************
gen v2010_age = ((v2010_alder-20)/70)
su v2010_age

********************************************
*Sex (2010): Mand==men; Kvinde==female
********************************************
ta v2010_koen
label variable v2010_koen "Sex"

********************************************
*Education (2010)
********************************************
gen v2011_houshincome = v2011_husindkom
*set don't want to tell to missing
recode v2011_houshincome (12=.)
*recode to range from 0 - 1
replace v2011_houshincome = ((v2011_houshincome-1)/10)

********************************************
*political interest (2010)
********************************************
gen v10_interest = v2010_re_q57
replace v10_interest = (4-v10_interest)/3

********************************************
*Political Efficacy (2010)
********************************************
alpha  v2010_re_q68_1 v2010_re_q68_2
ge v10_efficacy = v2010_re_q68_1 + v2010_re_q68_2
replace v10_efficacy = (v10_efficacy-2)/6

********************************************
*Create general left-right index
********************************************
foreach var of varlist v2010_re_q62_1 v2010_re_q62_2 v2010_re_q62_5 v2010_re_q62_7 v2010_re_q62_8 v2010_re_q62_10 {
gen x`var'=(`var'-1)/3
}
foreach var of varlist v2010_re_q62_3 v2010_re_q62_4 v2010_re_q62_6 {
gen x`var'=(4-`var')/3
}
egen lrgenmis=rowmiss( xv2010_re_q62_1 xv2010_re_q62_2 xv2010_re_q62_3 xv2010_re_q62_4 xv2010_re_q62_5 xv2010_re_q62_6 xv2010_re_q62_7 xv2010_re_q62_8 xv2010_re_q62_10)
egen lrgenind=rowmean (xv2010_re_q62_1 xv2010_re_q62_2 xv2010_re_q62_3 xv2010_re_q62_4 xv2010_re_q62_5 xv2010_re_q62_6 xv2010_re_q62_7 xv2010_re_q62_8 xv2010_re_q62_10) if lrgenmis<7
label variable lrgenind "General left-right scale:"
su lrgenind

********************************************
*
* Create Figure 1
*
********************************************
hist lability, xlabel(0(1)3) frac discrete ylabel(0(.1).8, angle(0) nogrid) title("Denmark") xtitle("Switches in Party Preferences") ytitle("Pecentage") plotregion(color(white)) graphregion(color(white)) bfcolor(gs10) blcolor(black)

********************************************
*
* Create Table 1 
*
********************************************
*Model 1
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome, irr 
*Model 2
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy lrgenind, irr

* Calculate predicted switches 1 SD above and below the mean on Openness
margins, at(v2010_open=(.39 .70)) vsquish
* Calculate predicted switches 1 SD above and below the mean on Extroversion
margins, at(v2010_ext=(.42 .71)) vsquish
* Calculate predicted switches over the range of political interest
margins, at(v10_interest=(0 .3333333 0.6666667 1)) vsquish

********************************************
*
*Create Figure 2
*
********************************************
*Create Figure 2 panel A
*Calculate marginal effect
margins, at(v2010_open=(.2(.1).9)) vsquish
*Create the graph 
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).6, angle(0) nogrid) ///
title("A - Openness to Experience (model 2)") ///
ytitle("Party Preference Switches") xtitle("Opennes to Experience") ///
recast(line)   plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) ///
addplot(hist v2010_open  if v2010_open>=.2 & v2010_open<=.9 & v2010_education!=. & v2011_houshincome!=. & v2010_polint!=. & v10_efficacy!=. & lrgenind!=. ///
, percent bin(100) yaxis(2) ylabel(0(2)12, axis(2) angle(0)) lcolor(gs2) yscale(line alt axis(2)) ytitle("Percentages Openness", axis(2))) 

*Create Figure 2 panel B
*Calculate marginal effect
margins, at(v2010_ext=(.2(.1).9)) vsquish
*Create the graph 
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).6, angle(0) nogrid) ///
title("B - Extraversion (model 2)") ///
ytitle("Party Preference Switches") xtitle("Extraversion") ///
recast(line)   plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) ///
addplot(hist v2010_ext  if v2010_ext>=.2 & v2010_ext<=.9 & v2010_education!=. & v2011_houshincome!=. & v2010_polint!=. & v10_efficacy!=. & lrgenind!=. ///
, percent bin(100) yaxis(2) ylabel(0(2)12, axis(2) angle(0)) lcolor(gs2) yscale(line alt axis(2)) ytitle("Percentages Extraversion", axis(2))) 

***********************************************
*
*Online Appendix A
*
***********************************************

***********************************************
*Table A1
***********************************************
su v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy lrgenind

*Cronbach's alpha
*External efficacy
alpha v2010_re_q68_1 v2010_re_q68_2
*Political ideology
alpha  v2010_re_q62_1-v2010_re_q62_8 v2010_re_q62_10

***********************************************
*Table A3
***********************************************
pwcorr v2010_open v2010_con v2010_ext v2010_agre v2010_neu  v10_interest v10_efficacy lrgenind if lability!=.

***********************************************
*Table A5
**********************************************
*Model 1
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest, irr 
*Model 2
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_efficacy, irr 
*Model 3
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome lrgenind, irr 

***********************************************
*
*Online Appendix C
*
***********************************************

*********************************************
***laver skift4: intention1o og intention11**
*********************************************

*vote intention in 2010
ta v2010_partivalg
*vote intention in 2011
ta v2011_partivalg
*create change variable
ge skift4= v2010_partivalg-v2011_partivalg
recode skift4 (-32/-1=1)
recode skift4 (1/32=1)
*descriptive
ta skift4
label variable skift4 "Switch between two surveys"

***********************************************
*Figure 1
***********************************************
hist skift4, xlabel(0 1) frac discrete ylabel(0(.1).8, angle(0) nogrid) ytitle("Percentage") title("") xtitle("Switches in Party Preferences") plotregion(color(white)) graphregion(color(white)) bfcolor(gs10) blcolor(black)

***********************************************
*Table C1
***********************************************
*Model 1
logit skift4 v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome, or 
*Model 2
logit skift4 v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy lrgenind, or 

***********************************************
*Figure C.2
***********************************************
*calculate marginal effect
margins, at(v2010_open=(.2(.1).9)) vsquish
*Plot figure
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).6, angle(0) nogrid) title("Openness to Experience (model 2)") ytitle("Party Preference Switches") xtitle("Opennes to Experience") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 

***********************************************
*
*Online Appendix F - Danish analyses with Three-Item measure
*
***********************************************

***********************************************
*Table F2
***********************************************
*Model 1
nbreg lability v2010_open_brit v2010_con v2010_ext_brit v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome, irr 
*Model 2
nbreg lability v2010_open_brit v2010_con v2010_ext_brit v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy lrgenind, irr

***********************************************
*Figure F1
***********************************************
*calculate marginal effect
margins, at(v2010_open=(.2(.1).9)) vsquish
*Plot figure
marginsplot, xlabel(.2(.1).9) ylabel(0(.1)1.1, angle(0) nogrid) ///
title("A - Openness to Experience (model 2)") ///
ytitle("Party Preference Switches") xtitle("Opennes to Experience") ///
recast(line)   plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) ///
addplot(hist v2010_open_brit  if v2010_open_brit>=.2 & v2010_open_brit<=.9 & v2010_education!=. & v2011_houshincome!=. & v2010_polint!=. & v10_efficacy!=. & lrgenind!=. ///
, percent bin(100) yaxis(2) ylabel(0(5)20, axis(2) angle(0)) lcolor(gs2) yscale(line alt axis(2)) ytitle("Percentages Openness", axis(2))) 

***********************************************
*
*Online Appendix G - Alternative Specifications of the Dependent Variable
*
***********************************************

***********************************************
*Table G1: Logistic regression
***********************************************
*Generate dummy variable from dependent variable
gen dum_lability = lability
recode dum_lability (2 3 = 1)

*Logistic regression: Baseline
logit dum_lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome, or
*Logistic regression:
logit dum_lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy lrgenind, or
*Calculate Effect Openness: 1 sd below the mean and  1 sd above the mean
margins, at(v2010_open=(.39 .70)) vsquish
*Calculate Effect Extroversion: 1 sd below the mean and  1 sd above the mean
margins, at(v2010_ext=(.42 .71)) vsquish

***********************************************
*Figure G1
***********************************************
*calculate marginal effect Openness
margins, at(v2010_open=(.2(.1).9))
*Create plot Openness
marginsplot, xlabel(.2(.1).9) ylabel(0 (.1)1, angle(0) nogrid) title("Openness to Experience (Model 2)") ytitle("Predicted Probability of Switching Party Preference") xtitle("Openness to Experience") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 
*calculate marginal effect Extraversion
margins, at(v2010_ext=(.2(.1).9))
*Create plot Extraversion
marginsplot, xlabel(.2(.1).9) ylabel(0 (.1)1, angle(0) nogrid) title("Extraversion (Model 2)") ytitle("Predicted Probability of Switching Party Preference") xtitle("Extraversion") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 

***********************************************
*Table G1: Logistic regression: Multinomial logit model
***********************************************
*Create dependent variable
gen lability_0_1_many = lability
ta lability_0_1_many
recode lability_0_1_many (3=2)

*Multinomial logit:
mlogit lability_0_1_many v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy lrgenind, base(0) rrr
*predicted probabilities of change once or changing 2/3 times
margins, at(v2010_open=(.2(.1).9)) predict(outcome(1))
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).4, angle(0) nogrid) title("Switch Party Preference Once") ytitle("Predicted Probability") xtitle("Openness to Experience") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 
margins, at(v2010_open=(.2(.1).9)) predict(outcome(2))
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).4, angle(0) nogrid) title("Switch Party Preference Two or Three Times") ytitle("Predicted Probability") xtitle("Openness to Experience") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 
*predicted probabilities of change once or changing 2/3 times
margins, at(v2010_ext=(.2(.1).9)) predict(outcome(1))
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).4, angle(0) nogrid) title("Switch Party Preference Once") ytitle("Predicted Probability") xtitle("Extraversion") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 
margins, at(v2010_ext=(.2(.1).9)) predict(outcome(2))
marginsplot, xlabel(.2(.1).9) ylabel(0(.1).4, angle(0) nogrid) title("Switch Party Preference Two or Three Times") ytitle("Predicted Probability") xtitle("Extraversion") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 

***********************************************
*
*Appendix H - Ideology with a four item measure
*
***********************************************

************************************************
*Create ideology measure using items in 2011
************************************************
 
*Homosexuals should have the same rights as everyone else
gen homosexuals = v2011_q62_7
replace homosexuals = (homosexuals-1)/3

*We should perserve our national customs in Denmark
gen nationalcustoms = 4-v2011_q62_4
replace nationalcustoms = nationalcustoms/3

*High income earners pay too litle taxes
gen redistribution = v2011_q62_1
replace redistribution = (redistribution-1)/3

*Income inequality is too great in this country and the greatest pay raise should be given to low income people
gen inequality = v2011_q62_2
replace inequality = (inequality-1)/3

alpha homosexuals nationalcustoms redistribution inequality
ge ideology_brit = homosexuals+nationalcustoms+redistribution+inequality
replace ideology_brit = ideology_brit/4
ta ideology_brit

***********************************************
*Table H1
***********************************************
*Model 1
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome ideology_brit, irr 
*Model 2
nbreg lability v2010_open v2010_con v2010_ext v2010_agre v2010_neu v2010_age v2010_koen i.v2010_education v2011_houshincome v10_interest v10_efficacy ideology_brit, irr
