**********************************************
*
*First run the .do file "Bakker_etal_PP_study1_codingvariables.do". 
*Afterwards run this .do file in order to replicat the results for the UK study reported in the paper
*
**********************************************

**********************************************
*
*Open data file
*
**********************************************
use "....\Study 2 UK\British_mothercopy.dta"

**********************************************
*
*Create lower panel of Figure 1 (UK study results)
*
**********************************************
hist count_change, xlabel(0(1)3) frac discrete ylabel(0(.1).8, angle(0) nogrid) title("UK") ytitle("Percentage") xtitle("Switches in Party Preferences") plotregion(color(white)) graphregion(color(white)) bfcolor(gs10) blcolor(black) ylabel(0(.1).8, nogrid)

**********************************************
*
*Create results for Table 2
*
**********************************************

*Model 1
nbreg count_change open con ext agre neu v05_age sex i.v05_education v05_income, irr vce (cluster ohid)
*Model 2
nbreg count_change open con ext agre neu v05_age  sex i.v05_education v05_income interest05 v05_efficacy  glideology, irr vce (cluster ohid)

*cacluate predicted switches one standard deviation below and above the mean
margins, at(open=(0.388 0.784)) vsquish
*Interest cacluate predicted switches one standard deviation below and above the mean
margins, at(interest05=(0 0.3333333 0.6666667 1)) vsquish

**********************************************
*
*Create Figure 2
*
**********************************************
*predicted switches over the range of Openness
margins, at (open=(0(.1)1)) vsquish
*Plot of predichted swithes
marginsplot, xlabel(0(.1)1) ylabel(0(.1).6, angle(0) nogrid) ///
title("A - Openness to Experience (model 2)") ///
ytitle("Party Preference Switches") xtitle("Opennes to Experience") ///
recast(line)   plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) ///
addplot(hist open  if v05_education!=. & v05_income!=. & interest05!=. & v05_efficacy!=. & glideology!=. ///
, bin(100) yaxis(2) ylabel(0(2)12, axis(2) angle(0)) lcolor(gs2) yscale(line alt axis(2)) ytitle("Frequency Openness", axis(2))) 

**********************************************
*
*Footnote 3
*
**********************************************
*create dummy indicating whether participants were present in all four waves and indicated their vote choice in each wave
gen sample_dum = 1 if count_change!=.
replace sample_dum=0 if count_change==.
*test attrition 
ttest open, by(sample_dum)
ttest con, by(sample_dum)
ttest ext, by(sample_dum)
ttest agre, by(sample_dum)
ttest neu, by(sample_dum)
ta count_change

**********************************************
*
*Supporting Information available online at the website of Politcial Psychology
*
**********************************************

**********************************************
*
*Supporting Information B  UK
*
**********************************************

**********************************************
*Table B1 Descriptive statistics
**********************************************
su open if count_change!=.
su con if count_change!=.
su ext if count_change!=.
su agre if count_change!=.
su neu if count_change!=.
su v05_age if count_change!=.
ta sex  if count_change!=.
su v05_income if count_change!=.
ta v05_education if count_change!=.
su interest05 if count_change!=.
su v05_efficacy if count_change!=.
su glideology if count_change!=.

*Cronbach's alpha's 
*Openness
alpha optrt5o1 optrt5o2 optrt5o3 if count_change!=., item 
*Conscientiousness 
alpha optrt5c1 optrt5c2 optrt5c3 if count_change!=., item 
*Extraversion
alpha optrt5e1 optrt5e2 optrt5e3 if count_change!=., item
*Agreeableness
alpha optrt5a1 optrt5a2 optrt5a3 if count_change!=., item std
*Neuroticism
alpha optrt5n1 optrt5n2 optrt5n3 if count_change!=.,  item std
*Efficacy
alpha poppola poppolb if count_change!=. 
*Ideology
alpha homo patriot eco if count_change!=., item

**********************************************
*Table B3: Correlation between the independent variables
**********************************************
pwcorr open con ext agre neu interest05 v05_efficacy glideology if count_change!=., sig

**********************************************
*Table B5: Negative Binomial Regression on the Number of Party Preference Switches (UK)
**********************************************
*Model 1: political interest
nbreg count_change open con ext agre neu v05_age sex i.v05_education v05_income interest05, irr vce (cluster ohid)
*Model 2: efficacy
nbreg count_change open con ext agre neu v05_age sex i.v05_education v05_income v05_efficacy, irr vce (cluster ohid)
*Model 3: ideology
nbreg count_change open con ext agre neu v05_age sex i.v05_education v05_income  glideology, irr vce (cluster ohid)

**********************************************
*
*Supporting Information D  UK Analyses with Party Attachment
*
**********************************************

**********************************************
*Table D1: Negative Binomial Regressions on Number of Party Preference Shift ///
* controlling for the Strength of Party Support (UK)
**********************************************
*Model 1
nbreg count_change open con ext agre neu v05_age ohgsex i.v05_education v05_income count_partisan, irr cluster(ohid)
*Model 2
nbreg count_change open con ext agre neu v05_age ohgsex i.v05_education v05_income count_partisan interest05 v05_efficacy glideology, irr cluster(ohid)
*predicted switches over the range of Openness
margins, at (open=(0(.1)1)) vsquish
*Plot of predichted swithes
marginsplot, xlabel(0(.1)1) ylabel(0(.1).6, angle(0) nogrid) ///
title("B - Strength of Party Support (Model 2)") ///
ytitle("Party Preference Switches") xtitle("Strength of Party Support") ///
recast(line)   plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) ///
addplot(hist count_partisan  if v05_education!=. & v05_income!=. & interest05!=. & v05_efficacy!=. & glideology!=. ///
, bin(100) yaxis(2) ylabel(0(2)12, axis(2) angle(0)) lcolor(gs2) yscale(line alt axis(2)) ytitle("Percentage Strength of Party Support", axis(2))) 

********************************************
*
*Supporting Information E  Extraversion X Party Activity
*
********************************************

*Create party activity varialbe
ta qorgaa, nol
gen partyactivity = qorgaa
*set missing to .
recode partyactivity (-7=.)
ta partyactivity if count_change!=.

********************************************
*Table E1: Interaction between Extraversion and Party Activity
********************************************
nbreg count_change open ext i.partyactivity  i.partyactivity#c.ext ////
con  agre neu v05_age ohgsex i.v05_education v05_income interest05 v05_efficacy  glideology, irr vce (cluster ohid)

**********************************************
*
*Supporting Information G  Alternative Specifications of the Dependent Variable 
*
**********************************************
*create dummy variabe
gen dum_count_change = count_change
recode dum_count_change (2 3 =1)
ta dum_count_change

*Create variable for multinomial model
gen count_change_0_1_many = count_change
recode count_change_0_1_many (3 =2)
ta count_change_0_1_many

**********************************************
*Table G2 Alternative Operationalization of Switches in Party Preferences: Logistic Regression and Multinomial Regression Models (UK sample)
**********************************************

*Logistic regression
*baseline model
logit dum_count_change open con ext agre neu v05_age ohgsex i.v05_education v05_income, or vce (cluster ohid)
*full model
logit dum_count_change open con ext agre neu v05_age ohgsex i.v05_education v05_income interest05 v05_efficacy  glideology, or vce (cluster ohid)

*Calculate predicted switches (left-hand column)
margins, at(open=(0.3965 0.7919)) vsquish
*Create Figure G4 Predicted Probability of Switching Party Preference: Logistic Regression Model (UK)
margins, at(open=(0(.1)1))
marginsplot, xlabel(.0(.1)1) ylabel(0 (.1).5, angle(0) nogrid) title("Openness to Experience (Model 2)") ytitle("Predicted Probability of Switching Party Preference") xtitle("Openness to Experience" ) recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 

*Multinomial regression (right-hand column)
mlogit count_change_0_1_many open con ext agre neu v05_age ohgsex i.v05_education v05_income interest05 v05_efficacy  glideology, rrr base(0) vce (cluster ohid)

*Create Figure G5 Predicted Probabilities of Switching Party Preference Once or Switching or More than Once: Multinomial Regression Model (UK)
*left-hand figure
margins, at(open=(0(.1)1)) predict(outcome(1))
marginsplot, xlabel(0(.1)1) ylabel(0(.1).3, angle(0) nogrid) title("Switch Party Preference Once") ytitle("Predicted Probability") xtitle("Openness to Experience") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 
*right-hand figure
margins, at(open=(0(.1)1)) predict(outcome(2))
marginsplot, xlabel(0(.1)1) ylabel(0(.1).3, angle(0) nogrid) title("Switch Party Preference Two or Three Times") ytitle("Predicted Probability") xtitle("Openness to Experience") recast(line)  plotopts(color(black)) recastci(rline) ciopts(color(white) lcolor(gs6) lpattern(dash)) plotregion(color(white)) graphregion(color(white)) 
